Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.txt	(revision 11954)
@@ -7,25 +7,25 @@
 .. module:: waeup.ikoba.app
 
-.. class:: Institution
+.. class:: Company
 
   The main Ikoba application object is given with
-  :class:`Institution`. It provides the main containers as faculties,
+  :class:`Company`. It provides the main containers as faculties,
   hostels, etc.
 
   .. attribute:: name
 
-     A string. The name of a institution.
+     A string. The name of a company.
 
   .. attribute:: faculties
 
      An arbitrary object containing "faculties". In the case of
-     `Institution` it is a container of type
+     `Company` it is a container of type
      `waeup.ikoba.interfaces.IFacultiesContainer`.
 
 
-Creating `Institution` instances
+Creating `Company` instances
 ===============================
 
-As :class:`Institution` instances make use of the Zope Component
+As :class:`Company` instances make use of the Zope Component
 Architecture (ZCA), we have to setup the basic component registries,
 before we can create instances. We do this by simply grokking the
@@ -34,18 +34,18 @@
 registries (this is done by the testlayer automatically).
 
-Now we can import the :class:`Institution` class and create an
+Now we can import the :class:`Company` class and create an
 instance:
 
-    >>> from waeup.ikoba.app import Institution
-    >>> myinstitution = Institution()
-    >>> myinstitution
-    <waeup.ikoba.app.Institution object at 0x...>
+    >>> from waeup.ikoba.app import Company
+    >>> mycompany = Company()
+    >>> mycompany
+    <waeup.ikoba.app.Company object at 0x...>
 
-Instances of `Institution` comply with the interface
-`waeup.ikoba.interfaces.IInstitution`:
+Instances of `Company` comply with the interface
+`waeup.ikoba.interfaces.ICompany`:
 
     >>> from zope.interface.verify import verifyClass
-    >>> from waeup.ikoba.interfaces import IInstitution
-    >>> verifyClass(IInstitution, Institution)
+    >>> from waeup.ikoba.interfaces import ICompany
+    >>> verifyClass(ICompany, Company)
     True
 
@@ -53,16 +53,16 @@
 interface:
 
-    >>> from waeup.ikoba.app import Institution
-    >>> myinstitution = Institution()
-    >>> myinstitution['configuration'].name
-    u'Sample Institution'
+    >>> from waeup.ikoba.app import Company
+    >>> mycompany = Company()
+    >>> mycompany['configuration'].name
+    u'Sample Company'
 
-  >>> myinstitution['users']
+  >>> mycompany['users']
   <waeup.ikoba.userscontainer.UsersContainer object at 0x...>
 
-  >>> myinstitution['datacenter']
+  >>> mycompany['datacenter']
   <waeup.ikoba.datacenter.DataCenter object at 0x...>
 
-  >>> myinstitution['configuration']
+  >>> mycompany['configuration']
   <waeup.ikoba.configuration.ConfigurationContainer object at 0x...>
 
@@ -103,9 +103,9 @@
 and setup a new Ikoba instance, we will get a message:
 
-   >>> from waeup.ikoba.app import Institution
-   >>> site = Institution()
+   >>> from waeup.ikoba.app import Company
+   >>> site = Company()
    Setup was called for
-   <waeup.ikoba.app.Institution object at 0x...>
+   <waeup.ikoba.app.Company object at 0x...>
 
-Apparently the plugin can do with the Institution object whatever it
+Apparently the plugin can do with the Company object whatever it
 likes. That's what plugins are for.
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/authentication.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/authentication.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/authentication.txt	(revision 11954)
@@ -11,7 +11,7 @@
 
   >>> from zope.component.hooks import setSite # only needed in tests
-  >>> from waeup.ikoba.app import Institution
+  >>> from waeup.ikoba.app import Company
   >>> root = getRootFolder()
-  >>> u = Institution()
+  >>> u = Company()
   >>> root['app'] = u
   >>> setSite(root['app'])                     # only needed in tests
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/batchprocessing.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/batchprocessing.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/batchprocessing.txt	(revision 11954)
@@ -21,6 +21,6 @@
 Create a site:
 
-    >>> from waeup.ikoba.app import Institution
-    >>> getRootFolder()['app'] = Institution()
+    >>> from waeup.ikoba.app import Company
+    >>> getRootFolder()['app'] = Company()
     >>> from zope.component.hooks import setSite
     >>> setSite(getRootFolder()['app'])
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.txt	(revision 11954)
@@ -9,9 +9,9 @@
 ===============================
 
-We create a institution to check the breadcrumb functionality.
-
-    >>> from waeup.ikoba.app import Institution
+We create a company to check the breadcrumb functionality.
+
+    >>> from waeup.ikoba.app import Company
     >>> root = getRootFolder()
-    >>> root['app'] = Institution()
+    >>> root['app'] = Company()
     >>> app = root['app']
 
@@ -25,5 +25,5 @@
     >>> blist1 = getBreadcrumbList(app, 'index')
     >>> blist1
-    [<waeup.ikoba.browser.breadcrumbs.InstitutionBreadcrumb object at 0x...>]
+    [<waeup.ikoba.browser.breadcrumbs.CompanyBreadcrumb object at 0x...>]
 
 A slightly more extensive list for the datacenter:
@@ -32,9 +32,9 @@
     >>> from pprint import pprint
     >>> pprint(blist2)
-    [<waeup.ikoba.browser.breadcrumbs.InstitutionBreadcrumb object at 0x...>,
+    [<waeup.ikoba.browser.breadcrumbs.CompanyBreadcrumb object at 0x...>,
      <waeup.ikoba.browser.breadcrumbs.AdministrationBreadcrumb object at 0x...>,
      <waeup.ikoba.browser.breadcrumbs.DataCenterBreadcrumb object at 0x...>]
 
-We get a breadcrumb for institution, administration area and data
+We get a breadcrumb for company, administration area and data
 center in that order.
 
@@ -47,11 +47,11 @@
 
      >>> pprint([(x.context, x.viewname) for x in blist2])
-     [(<waeup.ikoba.app.Institution object at 0x...>, 'index'),
-      (<waeup.ikoba.app.Institution object at 0x...>, 'administration'),
+     [(<waeup.ikoba.app.Company object at 0x...>, 'index'),
+      (<waeup.ikoba.app.Company object at 0x...>, 'administration'),
       (<waeup.ikoba.datacenter.DataCenter object at 0x...>, 'index')]
 
 The administration area breadcrumb might be a surprise, as there is no
 equivalent object in the ZODB. In fact the administration area is only
-a certain view (the 'administration' view) on the institution object.
+a certain view (the 'administration' view) on the company object.
 
 We will show below, how you can define breadcrumbs this way.
@@ -62,5 +62,5 @@
 
 This way we can make sure, that there are different breadcrumb lists
-generated for instance for the administration view of Institution
+generated for instance for the administration view of Company
 instances and the index view. While the first should look something
 like::
@@ -118,5 +118,5 @@
 
     >>> pprint(mybccontainer.getList())
-    [<...breadcrumbs.InstitutionBreadcrumb object at 0x...>,
+    [<...breadcrumbs.CompanyBreadcrumb object at 0x...>,
      <...breadcrumbs.AdministrationBreadcrumb object at 0x...>,
      <...breadcrumbs.UsersContainerBreadcrumb object at 0x...>]
@@ -128,5 +128,5 @@
 
 Now we can get breadcrumbs for contexts and view names. For example a
-breadcrumb for the 'index' view of our Institution object:
+breadcrumb for the 'index' view of our Company object:
 
     >>> from zope.component import getAdapter
@@ -134,5 +134,5 @@
     >>> b1 = getAdapter(app, IBreadcrumb, 'index')
     >>> b1
-    <waeup.ikoba.browser.breadcrumbs.InstitutionBreadcrumb object at 0x...>
+    <waeup.ikoba.browser.breadcrumbs.CompanyBreadcrumb object at 0x...>
 
 Breadcrumb objects provide a title:
@@ -168,7 +168,7 @@
 
     >>> b2.parent
-    (<waeup.ikoba.app.Institution object at 0x...>, 'administration')
-
-This result denotes a new context object (the Institution instance we
+    (<waeup.ikoba.app.Company object at 0x...>, 'administration')
+
+This result denotes a new context object (the Company instance we
 created above) and a view name ('administration').
 
@@ -188,5 +188,5 @@
 As you can see, we get an AdministrationBreadcrumb, although the
 context object, for which the breadcrumb was created is also the
-Institution instance as above:
+Company instance as above:
 
     >>> b3.context is b1.context
@@ -197,5 +197,5 @@
     >>> context, viewname = b3.parent
     >>> context, viewname
-    (<waeup.ikoba.app.Institution object at 0x...>, 'index')
+    (<waeup.ikoba.app.Company object at 0x...>, 'index')
 
 We create last breadcrumb:
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/browser.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/browser.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/browser.txt	(revision 11954)
@@ -4,10 +4,10 @@
 Here we visit all parts of a Ikoba portal using a browser.
 
-Institution
+Company
 ==========
 
 We can watch universities in the browser.
 
-We create an institution object and put into the ZODB root::
+We create an company object and put into the ZODB root::
 
   >>> root = getRootFolder()
@@ -15,12 +15,12 @@
   []
 
-  >>> from waeup.ikoba.app import Institution
-  >>> u = Institution()
-  >>> root['myinstitution'] = u
+  >>> from waeup.ikoba.app import Company
+  >>> u = Company()
+  >>> root['mycompany'] = u
   >>> list(root)
-  [u'myinstitution']
+  [u'mycompany']
 
   >>> from zope.component.hooks import setSite
-  >>> setSite(root['myinstitution'])
+  >>> setSite(root['mycompany'])
 
 To make sure, we can 'watch' pages, we first have to initialize out
@@ -30,7 +30,7 @@
   >>> browser = Browser()
 
-Let's get the default view of a institution::
-
-  >>> browser.open('http://localhost/myinstitution')
+Let's get the default view of a company::
+
+  >>> browser.open('http://localhost/mycompany')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -55,5 +55,5 @@
 The contact form for anonymous users is called 'Enquiries'::
 
-  >>> browser.open('http://localhost/myinstitution')
+  >>> browser.open('http://localhost/mycompany')
   >>> browser.getLink('Enquiries').click()
   >>> browser.getControl('Send').click()
@@ -74,7 +74,7 @@
 Registered users with an email address can request a password change:
 
-  >>> root['myinstitution']['users'].addUser('forgetful', 'secret',title='Bob Forgetful',
+  >>> root['mycompany']['users'].addUser('forgetful', 'secret',title='Bob Forgetful',
   ...                               description='A forgetful user', email='aa@aa.ng')
-  >>> browser.open('http://localhost/myinstitution/changepw')
+  >>> browser.open('http://localhost/mycompany/changepw')
   >>> browser.getControl(name="form.identifier").value = 'forgetful'
   >>> browser.getControl(name="form.email").value = 'aa@aa.ng'
@@ -91,13 +91,13 @@
 We can then get an edit view of the configuration container::
 
-  >>> browser.open('http://localhost/myinstitution/configuration')
-  >>> print browser.contents
-  <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
-  ...<form action="http://localhost/myinstitution/configuration/@@index"
-  ...
-
-The edit form contains the default value for the institution name::
-
-  >>> 'Sample Institution' in browser.contents
+  >>> browser.open('http://localhost/mycompany/configuration')
+  >>> print browser.contents
+  <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
+  ...<form action="http://localhost/mycompany/configuration/@@index"
+  ...
+
+The edit form contains the default value for the company name::
+
+  >>> 'Sample Company' in browser.contents
   True
 
@@ -110,5 +110,5 @@
   ...
 
-  >>> browser.open('http://localhost/myinstitution/configuration')
+  >>> browser.open('http://localhost/mycompany/configuration')
   >>> browser.getControl("Update plugins").click()
   >>> print browser.contents
@@ -120,5 +120,5 @@
 and is properly rendered on the frontpage of the portal:
 
-  >>> browser.open('http://localhost/myinstitution')
+  >>> browser.open('http://localhost/mycompany')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -134,5 +134,5 @@
 If we change to German so that the German part of frontpage.rst is rendered:
 
-  >>> browser.open('http://localhost/myinstitution//@@change_language?lang=de')
+  >>> browser.open('http://localhost/mycompany//@@change_language?lang=de')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -147,5 +147,5 @@
 Switch back to English:
 
-  >>> browser.open('http://localhost/myinstitution//@@change_language?lang=en')
+  >>> browser.open('http://localhost/mycompany//@@change_language?lang=en')
 
 
@@ -153,5 +153,5 @@
 ============
 
-  >>> browser.open('http://localhost/myinstitution')
+  >>> browser.open('http://localhost/mycompany')
   >>> browser.getLink('Portal Users').click()
   >>> print browser.contents
@@ -187,10 +187,10 @@
 manually by setting the roles attribute:
 
-  >>> print root['myinstitution']['users']['bob'].roles
+  >>> print root['mycompany']['users']['bob'].roles
   []
-  >>> root['myinstitution']['users']['bob'].roles = ['waeup.UsersManager']
-  >>> print root['myinstitution']['users']['bob'].roles
+  >>> root['mycompany']['users']['bob'].roles = ['waeup.UsersManager']
+  >>> print root['mycompany']['users']['bob'].roles
   ['waeup.UsersManager']
-  >>> browser.open('http://localhost/myinstitution/users')
+  >>> browser.open('http://localhost/mycompany/users')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -200,5 +200,5 @@
 Users can't be added twice:
 
-  >>> browser.open('http://localhost/myinstitution/users/add')
+  >>> browser.open('http://localhost/mycompany/users/add')
   >>> browser.getControl(name="form.name").value = 'bob'
   >>> browser.getControl(name="form.title").value = 'Bob The User'
@@ -215,5 +215,5 @@
 Users can be deleted:
 
-  >>> browser.open('http://localhost/myinstitution/users')
+  >>> browser.open('http://localhost/mycompany/users')
   >>> browser.getControl("Remove", index=0).click()
   >>> 'User account bob successfully deleted' in browser.contents
@@ -227,5 +227,5 @@
 Let's enter the contact form::
 
-  >>> browser.open('http://localhost/myinstitution/contactadmin')
+  >>> browser.open('http://localhost/mycompany/contactadmin')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -236,5 +236,5 @@
 contact@waeup.org)::
 
-  >>> browser.open('http://localhost/myinstitution/contactadmin')
+  >>> browser.open('http://localhost/mycompany/contactadmin')
   >>> browser.getControl(name='form.body').value = "test message"
   >>> browser.getControl('Send').click()
@@ -253,5 +253,5 @@
 The data center helps us uploading files for later import or similar.
 
-  >>> browser.open('http://localhost/myinstitution')
+  >>> browser.open('http://localhost/mycompany')
   >>> browser.getLink('Data Center').click()
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/captcha.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/captcha.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/captcha.py	(revision 11954)
@@ -32,5 +32,5 @@
     ICaptchaRequest, ICaptchaResponse, ICaptcha, ICaptchaConfig,
     ICaptchaManager)
-from waeup.ikoba.interfaces import IInstitution
+from waeup.ikoba.interfaces import ICompany
 
 #
@@ -322,5 +322,5 @@
     # A test page to see a captcha in action
     grok.name('captcha')
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.require('waeup.Public')
     title = 'Captcha Test'
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/exceptions.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/exceptions.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/exceptions.py	(revision 11954)
@@ -64,5 +64,5 @@
     """A page rendered when an object cannot be found.
 
-    XXX: This page won't work for objects above a w.k.Institution.
+    XXX: This page won't work for objects above a w.k.Company.
     """
     grok.context(INotFound)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/interfaces.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/interfaces.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/interfaces.py	(revision 11954)
@@ -21,5 +21,5 @@
 from zope.interface import Interface, Attribute
 from waeup.ikoba.interfaces import (
-    IIkobaObject, IInstitution, IUsersContainer, IDataCenter, validate_email)
+    IIkobaObject, ICompany, IUsersContainer, IDataCenter, validate_email)
 from waeup.ikoba.interfaces import MessageFactory as _
 
@@ -161,5 +161,5 @@
 
         If no `headerline` is given, a default will be rendered (name
-        of institution).
+        of company).
 
         If no `title` is given, nothing will be rendered.
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/layout.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/layout.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/layout.py	(revision 11954)
@@ -227,5 +227,5 @@
 
     def getAppTitle(self):
-        return getattr(grok.getSite()['configuration'], 'name', u'Sample Institution')
+        return getattr(grok.getSite()['configuration'], 'name', u'Sample Company')
 
     def getAppAcronym(self):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pdf.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pdf.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pdf.py	(revision 11954)
@@ -710,5 +710,5 @@
             doc, 'ikoba_headtitle', getattr(
                 site_config, 'name',
-                u'Sample Institution'))
+                u'Sample Company'))
         canvas.setFont("Helvetica-Bold", 18)
         if self.header_logo_left_path is not None:
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companypage.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companypage.pt	(revision 11954)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companypage.pt	(revision 11954)
@@ -0,0 +1,1 @@
+<span tal:replace="structure view/frontpage">Frontpage</span>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companyrss20feed.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companyrss20feed.pt	(revision 11954)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companyrss20feed.pt	(revision 11954)
@@ -0,0 +1,59 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<rss version="2.0"
+     xmlns:tal="http://xml.zope.org/namespaces/tal"
+     xmlns:atom="http://www.w3.org/2005/Atom">
+  <channel>
+    <title>
+      <tal:block tal:content="view/title"/>
+      <tal:block
+	  tal:define="title view/contexttitle"
+	  tal:condition="title"> - <tal:block content="title"/>
+      </tal:block>
+    </title>
+    <link
+	tal:content="view/link"></link>
+    <description
+	tal:content="view/description"></description>
+    <language
+	tal:condition="view/language"
+	tal:content="view/language"></language>
+    <pubDate
+	tal:condition="view/date"
+	tal:content="view/date"></pubDate>
+    <lastBuildDate
+	tal:condition="view/buildDate"
+	tal:content="view/buildDate"></lastBuildDate>
+    <managingEditor
+	tal:condition="view/editor"
+	tal:content="view/editor"></managingEditor>
+    <webMaster
+	tal:condition="view/webmaster"
+	tal:content="view/webmaster"></webMaster>
+    <atom:link
+	tal:attributes="href string:${view/link}@@feeds/${view/name}"
+	rel="self" type="application/rss+xml" />
+    <item
+	tal:repeat="item view/entries">
+      <title
+	  tal:content="item/title"></title>
+      <description
+	  tal:content="item/description"></description>
+      <guid
+	  tal:content="item/guid"
+	  tal:define="isPermaLink item/isPermaLink|nothing"
+	  tal:attributes="isPermaLink python:isPermaLink and 'true' or 'false'"></guid>
+      <link
+	  tal:condition="item/link|nothing"
+	  tal:content="item/link"></link>
+      <author
+	  tal:condition="item/author|nothing"
+	  tal:content="item/author"></author>
+      <category
+	  tal:condition="item/category|nothing"
+	  tal:content="item/category"></category>
+      <pubDate
+	  tal:condition="item/pubDate|nothing"
+	  tal:content="item/pubDate"></pubDate>
+    </item>
+  </channel>
+</rss>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionpage.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionpage.pt	(revision 11952)
+++ 	(revision )
@@ -1,1 +1,0 @@
-<span tal:replace="structure view/frontpage">Frontpage</span>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionrss20feed.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionrss20feed.pt	(revision 11952)
+++ 	(revision )
@@ -1,59 +1,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<rss version="2.0"
-     xmlns:tal="http://xml.zope.org/namespaces/tal"
-     xmlns:atom="http://www.w3.org/2005/Atom">
-  <channel>
-    <title>
-      <tal:block tal:content="view/title"/>
-      <tal:block
-	  tal:define="title view/contexttitle"
-	  tal:condition="title"> - <tal:block content="title"/>
-      </tal:block>
-    </title>
-    <link
-	tal:content="view/link"></link>
-    <description
-	tal:content="view/description"></description>
-    <language
-	tal:condition="view/language"
-	tal:content="view/language"></language>
-    <pubDate
-	tal:condition="view/date"
-	tal:content="view/date"></pubDate>
-    <lastBuildDate
-	tal:condition="view/buildDate"
-	tal:content="view/buildDate"></lastBuildDate>
-    <managingEditor
-	tal:condition="view/editor"
-	tal:content="view/editor"></managingEditor>
-    <webMaster
-	tal:condition="view/webmaster"
-	tal:content="view/webmaster"></webMaster>
-    <atom:link
-	tal:attributes="href string:${view/link}@@feeds/${view/name}"
-	rel="self" type="application/rss+xml" />
-    <item
-	tal:repeat="item view/entries">
-      <title
-	  tal:content="item/title"></title>
-      <description
-	  tal:content="item/description"></description>
-      <guid
-	  tal:content="item/guid"
-	  tal:define="isPermaLink item/isPermaLink|nothing"
-	  tal:attributes="isPermaLink python:isPermaLink and 'true' or 'false'"></guid>
-      <link
-	  tal:condition="item/link|nothing"
-	  tal:content="item/link"></link>
-      <author
-	  tal:condition="item/author|nothing"
-	  tal:content="item/author"></author>
-      <category
-	  tal:condition="item/category|nothing"
-	  tal:content="item/category"></category>
-      <pubDate
-	  tal:condition="item/pubDate|nothing"
-	  tal:content="item/pubDate"></pubDate>
-    </item>
-  </channel>
-</rss>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_async.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_async.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_async.py	(revision 11954)
@@ -8,5 +8,5 @@
 from zope.security.interfaces import Unauthorized
 from zope.testbrowser.testing import Browser
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.async import AsyncJob, get_job_id
 from waeup.ikoba.interfaces import IJobManager
@@ -29,5 +29,5 @@
         self.storage = os.path.join(self.workdir, 'storage')
         os.mkdir(self.storage)
-        app = Institution()
+        app = Company()
         app['datacenter'].setStoragePath(self.storage)
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/viewlets.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/viewlets.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/viewlets.py	(revision 11954)
@@ -24,8 +24,8 @@
 from zope.traversing.browser import absoluteURL
 from waeup.ikoba.browser.pages import (
-    InstitutionPage, DatacenterPage,
+    CompanyPage, DatacenterPage,
     UsersContainerPage, UserManageFormPage)
 from waeup.ikoba.browser.interfaces import (
-    IBreadcrumbContainer, IInstitution, IUsersContainer)
+    IBreadcrumbContainer, ICompany, IUsersContainer)
 from waeup.ikoba.interfaces import (
     IIkobaUtils, IIkobaObject, IIkobaXMLExporter,
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/frontpage.html
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/frontpage.html	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/frontpage.html	(revision 11954)
@@ -16,5 +16,5 @@
 Ikoba is part of the
 <a href="https://waeup.org/">West African eUniversity Project (WAeUP)</a>.
-It is a powerful and comprehensive Student Management System.
+It is a powerful and comprehensive Online Application and Registration Portal.
 The software is written in Python and built upon the Open Source
 <a href="http://grok.zope.org/">Grok Web Framework</a>.
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/imagestorage.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/imagestorage.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/imagestorage.py	(revision 11954)
@@ -285,5 +285,5 @@
     want to change this path -- it is dynamic. That means, if you call
     the file store from 'within' a site, the root path will be located
-    inside this site (a :class:`waeup.ikoba.Institution` instance). If
+    inside this site (a :class:`waeup.ikoba.Company` instance). If
     you call it from 'outside' a site some temporary dir (always the
     same during lifetime of the file store instance) will be used. The
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/index.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/index.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/index.txt	(revision 11954)
@@ -20,5 +20,5 @@
    accesscodes/api.txt
    jambtables/api.txt
-   institution/api.txt
+   company/api.txt
    utils/api.txt
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/de/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/de/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/de/LC_MESSAGES/waeup.ikoba.po	(revision 11954)
@@ -1073,13 +1073,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of Institution"
+msgid "Name of Company"
 msgstr "Name der Universität"
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample Institution"
+msgid "Sample Company"
 msgstr "Deomo-Universität"
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of Institution"
+msgid "Abbreviated Title of Company"
 msgstr "Abkürzung"
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/en/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/en/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/en/LC_MESSAGES/waeup.ikoba.po	(revision 11954)
@@ -1004,13 +1004,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of Institution"
+msgid "Name of Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample Institution"
+msgid "Sample Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of Institution"
+msgid "Abbreviated Title of Company"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/fr/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/fr/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/fr/LC_MESSAGES/waeup.ikoba.po	(revision 11954)
@@ -1076,13 +1076,13 @@
 #: waeup/ikoba/interfaces.py:595
 #, fuzzy
-msgid "Name of Institution"
+msgid "Name of Company"
 msgstr "Nom du département"
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample Institution"
+msgid "Sample Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of Institution"
+msgid "Abbreviated Title of Company"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ha/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ha/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ha/LC_MESSAGES/waeup.ikoba.po	(revision 11954)
@@ -1005,13 +1005,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of Institution"
+msgid "Name of Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample Institution"
+msgid "Sample Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of Institution"
+msgid "Abbreviated Title of Company"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ig/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ig/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ig/LC_MESSAGES/waeup.ikoba.po	(revision 11954)
@@ -1005,13 +1005,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of Institution"
+msgid "Name of Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample Institution"
+msgid "Sample Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of Institution"
+msgid "Abbreviated Title of Company"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/waeup.ikoba.pot
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/waeup.ikoba.pot	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/waeup.ikoba.pot	(revision 11954)
@@ -1011,13 +1011,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of Institution"
+msgid "Name of Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample Institution"
+msgid "Sample Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of Institution"
+msgid "Abbreviated Title of Company"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/yo/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/yo/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/yo/LC_MESSAGES/waeup.ikoba.po	(revision 11954)
@@ -1005,13 +1005,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of Institution"
+msgid "Name of Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample Institution"
+msgid "Sample Company"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of Institution"
+msgid "Abbreviated Title of Company"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/browser.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/browser.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/browser.py	(revision 11954)
@@ -20,5 +20,5 @@
 import grok
 from waeup.ikoba.browser.layout import UtilityView
-from waeup.ikoba.interfaces import IInstitution
+from waeup.ikoba.interfaces import ICompany
 from waeup.ikoba.interfaces import MessageFactory as _
 
@@ -26,5 +26,5 @@
     """View to execute mandate.
     """
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.name('mandate')
     grok.require('waeup.Public')
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/container.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/container.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/container.py	(revision 11954)
@@ -49,5 +49,5 @@
 
 class MandatesPlugin(grok.GlobalUtility):
-    """A plugin that creates container for mandates inside a institution.
+    """A plugin that creates container for mandates inside a company.
     """
     grok.implements(IIkobaPluggable)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/tests.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/tests.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/tests.py	(revision 11954)
@@ -27,5 +27,5 @@
 from zope.component import createObject
 from zope.component.hooks import setSite, clearSite
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.interfaces import IUserAccount
 from waeup.ikoba.mandates.interfaces import (
@@ -63,5 +63,5 @@
 
         # Setup a sample site for each test
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/catalog.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/catalog.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/catalog.py	(revision 11954)
@@ -19,5 +19,5 @@
 """
 import grok
-from waeup.ikoba.interfaces import IInstitution
+from waeup.ikoba.interfaces import ICompany
 from waeup.ikoba.payments.interfaces import IPayment
 
@@ -25,5 +25,5 @@
     """A catalog for all payments.
     """
-    grok.site(IInstitution)
+    grok.site(ICompany)
     grok.name('payments_catalog')
     grok.context(IPayment)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/testing.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/testing.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/testing.py	(revision 11954)
@@ -126,5 +126,5 @@
         maybe_grok, setUpZope, cleanUpZope,
         )
-      from waeup.ikoba.app import Institution
+      from waeup.ikoba.app import Company
 
       class MyTestCase(unittest.TestCase):
@@ -148,5 +148,5 @@
 
           def test_jambdata_in_site(self):
-              u = Institution()
+              u = Company()
               self.assertTrue('jambdata' in u.keys())
               return
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_app.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_app.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_app.py	(revision 11954)
@@ -22,29 +22,29 @@
 from zope.component.hooks import setSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.interfaces import (
-    IInstitution, IJobManager, VIRT_JOBS_CONTAINER_NAME)
+    ICompany, IJobManager, VIRT_JOBS_CONTAINER_NAME)
 from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 
-class InstitutionTests(FunctionalTestCase):
+class CompanyTests(FunctionalTestCase):
 
     layer = FunctionalLayer
 
     def setUp(self):
-        super(InstitutionTests, self).setUp()
+        super(CompanyTests, self).setUp()
         self.workdir = tempfile.mkdtemp()
-        self.getRootFolder()['app'] = Institution()
+        self.getRootFolder()['app'] = Company()
         self.app = self.getRootFolder()['app']
         return
 
     def tearDown(self):
-        super(InstitutionTests, self).tearDown()
+        super(CompanyTests, self).tearDown()
         shutil.rmtree(self.workdir)
         return
 
     def test_ifaces(self):
-        institution = Institution()
-        assert verifyClass(IInstitution, Institution)
-        assert verifyObject(IInstitution, institution)
+        company = Company()
+        assert verifyClass(ICompany, Company)
+        assert verifyObject(ICompany, company)
         return
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_imagestorage.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_imagestorage.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_imagestorage.py	(revision 11954)
@@ -27,5 +27,5 @@
 from zope.component.hooks import setSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 from waeup.ikoba.imagestorage import (
@@ -228,5 +228,5 @@
         self.fd = open(self.samplefile, 'r')
         self.fd2 = open(self.otherfile, 'r')
-        self.getRootFolder()['app'] = Institution()
+        self.getRootFolder()['app'] = Company()
         self.app = self.getRootFolder()['app']
         self.app['datacenter'].setStoragePath(self.workdir)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_maintenance.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_maintenance.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_maintenance.py	(revision 11954)
@@ -9,5 +9,5 @@
 from zope.component.hooks import setSite
 from zope.interface import Interface, implements
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.maintenance import update_catalog
 from waeup.ikoba.testing import FunctionalTestCase, FunctionalLayer
@@ -41,5 +41,5 @@
         super(UpdateCatalogTests, self).setUp()
         # Setup a sample site for each test
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_objecthistory.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_objecthistory.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_objecthistory.py	(revision 11954)
@@ -25,5 +25,5 @@
 from zope.security.management import newInteraction, endInteraction
 from zope.security.testing import Principal, Participation
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.interfaces import IObjectHistory, IIkobaObject
 from waeup.ikoba.testing import FunctionalTestCase, FunctionalLayer
@@ -43,5 +43,5 @@
 
         # Prepopulate ZODB
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_smtp.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_smtp.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_smtp.py	(revision 11954)
@@ -27,5 +27,5 @@
 from zope.component.hooks import setSite
 from zope.sendmail.interfaces import IMailDelivery
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.interfaces import IMailService
 from waeup.ikoba.smtp import (
@@ -341,5 +341,5 @@
         super(ExternalMailerTests, self).setUp()
         # Setup a sample site for each test
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/userscontainer.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/userscontainer.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/userscontainer.py	(revision 11954)
@@ -92,5 +92,5 @@
                     obj= object
                     path = ''
-                    while obj.__class__.__name__ != 'Institution':
+                    while obj.__class__.__name__ != 'Company':
                         path = '%s/' % obj.__name__ + path
                         obj = obj.__parent__
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/batching.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/batching.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/batching.txt	(revision 11954)
@@ -20,5 +20,5 @@
 * accepts a single data type identified by an interface.
 
-* knows about the places inside a site (Institution) where to store,
+* knows about the places inside a site (Company) where to store,
   remove or update the data.
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/browser.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/browser.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/browser.py	(revision 11954)
@@ -25,5 +25,5 @@
 from waeup.ikoba.interfaces import IObjectHistory
 
-from waeup.ikoba.interfaces import IInstitution
+from waeup.ikoba.interfaces import ICompany
 
 class ReindexPage(UtilityView, grok.View):
@@ -32,5 +32,5 @@
     Reindexes a catalog. For managers only.
     """
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.name('reindex')
     grok.require('waeup.managePortal')
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/helpers.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/helpers.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/helpers.txt	(revision 11954)
@@ -185,5 +185,5 @@
      ... <BLANKLINE>
      ... <body>
-     ... <form action="http://localhost/myinstitution/faculties/TF/add"
+     ... <form action="http://localhost/mycompany/faculties/TF/add"
      ...       method="post" class="edit-form"
      ...       enctype="multipart/form-data">
@@ -194,5 +194,5 @@
      ... """)
      <BLANKLINE>
-     <form action="http://localhost/myinstitution/faculties/TF/add"
+     <form action="http://localhost/mycompany/faculties/TF/add"
            method="post" class="edit-form"
            enctype="multipart/form-data">
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/logger.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/logger.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/logger.py	(revision 11954)
@@ -67,7 +67,7 @@
 
 The datacenter and its storage are created automatically when you
-create a :class:`waeup.ikoba.app.Institution`. This also means that
+create a :class:`waeup.ikoba.app.Company`. This also means that
 logging with the `Logger` mix-in will work only inside so-called sites
-(`Institution` instances put into ZODB are such `sites`).
+(`Company` instances put into ZODB are such `sites`).
 
 Other components in this module help to make everything work.
@@ -386,6 +386,6 @@
     return
 
-from waeup.ikoba.interfaces import IInstitution
-@grok.subscribe(IInstitution, grok.IObjectRemovedEvent)
+from waeup.ikoba.interfaces import ICompany
+@grok.subscribe(ICompany, grok.IObjectRemovedEvent)
 def handle_site_removed(obj, event):
     collector = queryUtility(ILoggerCollector)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_batching.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_batching.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_batching.py	(revision 11954)
@@ -30,5 +30,5 @@
 from zope.component.interfaces import IFactory
 from zope.interface import Interface, implements, verify
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.interfaces import (
     ICSVExporter, IBatchProcessor, IExportJobContainer, IJobManager,
@@ -137,5 +137,5 @@
 
         # Setup a sample site for each test
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
@@ -597,5 +597,5 @@
     def test_active_site(self):
         # we get the datafinder if one is installed and site set
-        self.getRootFolder()['app'] = Institution()
+        self.getRootFolder()['app'] = Company()
         finder = getUtility(IExportContainerFinder)
         setSite(self.getRootFolder()['app'])
@@ -606,5 +606,5 @@
     def test_broken_site(self):
         # if the current site has no ExportContainer, we get None
-        self.getRootFolder()['app'] = Institution()
+        self.getRootFolder()['app'] = Company()
         app = self.getRootFolder()['app']
         del app['datacenter'] # datacenter _is_ the export container
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_converters.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_converters.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_converters.py	(revision 11954)
@@ -32,5 +32,5 @@
     Interface, implements, invariant, Invalid, implementedBy, verify)
 
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 from waeup.ikoba.interfaces import (
@@ -155,5 +155,5 @@
 
         # Setup a sample site for each test
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_logger.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_logger.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_logger.py	(revision 11954)
@@ -25,5 +25,5 @@
 from zope.component.hooks import setSite, clearSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 
@@ -49,5 +49,5 @@
         super(LoggersTests, self).setUp()
         # Setup a sample site for each test
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         self.dc_root2 = None
@@ -223,5 +223,5 @@
 
         # Setup a sample site for each test
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
@@ -281,5 +281,5 @@
         super(LoggerCollectorTests, self).setUp()
         # Setup a sample site for each test
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
@@ -377,5 +377,5 @@
         super(LogfileChangeTests, self).setUp()
         # Setup a sample site for each test
-        app = Institution()
+        app = Company()
         self.dc_root = tempfile.mkdtemp()
         self.dc_root_new = None
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/webservices.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/webservices.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/webservices.py	(revision 11954)
@@ -20,5 +20,5 @@
 from zope.component import getUtility
 from zope.catalog.interfaces import ICatalog
-from waeup.ikoba.interfaces import IInstitution, application_sessions_vocab
+from waeup.ikoba.interfaces import ICompany, application_sessions_vocab
 
 class XMLRPCPermission(grok.Permission):
@@ -34,5 +34,5 @@
     grok.permissions('waeup.xmlrpc',)
 
-class InstitutionXMLRPC(grok.XMLRPC):
+class CompanyXMLRPC(grok.XMLRPC):
     """XMLRPC webservices for Ikoba portals.
 
@@ -40,5 +40,5 @@
     but positional arguments only.
     """
-    grok.context(IInstitution)
+    grok.context(ICompany)
 
     @grok.require('waeup.Public')

Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.py	(revision 11954)
@@ -25,5 +25,5 @@
 from waeup.ikoba.mandates.container import MandatesContainer
 from waeup.ikoba.interfaces import (
-    IInstitution, IIkobaPluggable, IObjectUpgradeEvent, IJobManager,
+    ICompany, IIkobaPluggable, IObjectUpgradeEvent, IJobManager,
     VIRT_JOBS_CONTAINER_NAME)
 from waeup.ikoba.userscontainer import UsersContainer
@@ -32,8 +32,8 @@
 from waeup.ikoba.configuration import ConfigurationContainer
 
-class Institution(grok.Application, grok.Container, Logger):
-    """A institution.
+class Company(grok.Application, grok.Container, Logger):
+    """A company.
     """
-    grok.implements(IInstitution)
+    grok.implements(ICompany)
 
     # Setup authentication for this app. Note: this is only
@@ -44,5 +44,5 @@
 
     def __init__(self, *args, **kw):
-        super(Institution, self).__init__(*args, **kw)
+        super(Company, self).__init__(*args, **kw)
         self.setup()
         return
@@ -85,5 +85,5 @@
         self.logger.info('Plugin update finished.')
         return
-attrs_to_fields(Institution)
+attrs_to_fields(Company)
 
 class ObjectUpgradeEvent(ObjectEvent):
@@ -92,8 +92,8 @@
     grok.implements(IObjectUpgradeEvent)
 
-@grok.subscribe(Institution, grok.IObjectAddedEvent)
-def handle_institution_added(app, event):
-    """If a institution is added, a message is logged.
+@grok.subscribe(Company, grok.IObjectAddedEvent)
+def handle_company_added(app, event):
+    """If a company is added, a message is logged.
     """
-    app.logger.info('Institution `%s` added.' % getattr(app, '__name__', None))
+    app.logger.info('Company `%s` added.' % getattr(app, '__name__', None))
     return
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.py	(revision 11954)
@@ -28,5 +28,5 @@
 from waeup.ikoba.browser.interfaces import (
     IBreadcrumb, IBreadcrumbIgnorable, IBreadcrumbContainer, IIkobaObject,
-    IInstitution, IUsersContainer, IDataCenter,
+    ICompany, IUsersContainer, IDataCenter,
     )
 from waeup.ikoba.reports import IReportsContainer
@@ -86,8 +86,8 @@
         return self.viewname
 
-class InstitutionBreadcrumb(Breadcrumb):
-    """A breadcrumb for institution index pages.
-    """
-    grok.context(IInstitution)
+class CompanyBreadcrumb(Breadcrumb):
+    """A breadcrumb for company index pages.
+    """
+    grok.context(ICompany)
     title = _(u'Home')
     parent = None
@@ -97,10 +97,10 @@
 
     Here we need a special `parent()` implementation, because the
     parent object is not a real parent (the Institution object has no
     valid parent in terms of breadcrumbs). Instead it is the
     ``administration`` view of the same context the ``manage`` page
     itself is bound to.
     """
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.name('manage')
     title = _(u'Portal Settings')
@@ -113,7 +113,7 @@
 
 class AdministrationBreadcrumb(Breadcrumb):
-    """A breadcrumb for administration areas of Institution instances.
-    """
-    grok.context(IInstitution)
+    """A breadcrumb for administration areas of Company instances.
+    """
+    grok.context(ICompany)
     grok.name('administration')
     title = _(u'Administration')
@@ -97,10 +97,10 @@
 
     Here we need a special `parent()` implementation, because the
-    parent object is not a real parent (the Institution object has no
+    parent object is not a real parent (the Company object has no
     valid parent in terms of breadcrumbs). Instead it is the
     ``administration`` view of the same context the ``manage`` page
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pages.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pages.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pages.py	(revision 11954)
@@ -46,5 +46,5 @@
     IkobaDisplayFormPage, NullValidator)
 from waeup.ikoba.browser.interfaces import (
-    IInstitution, ICaptchaManager, IChangePassword)
+    ICompany, ICaptchaManager, IChangePassword)
 from waeup.ikoba.browser.layout import jsaction, action, UtilityView
 from waeup.ikoba.interfaces import MessageFactory as _
@@ -325,5 +325,5 @@
 class ContactAdminForm(IkobaForm):
     grok.name('contactadmin')
-    #grok.context(IInstitution)
+    #grok.context(ICompany)
     grok.template('contactform')
     grok.require('waeup.Authenticated')
@@ -405,13 +405,13 @@
 
 #
 # Institution related pages...
 #
 
-class InstitutionPage(IkobaDisplayFormPage):
-    """ The main institution page.
+class CompanyPage(IkobaDisplayFormPage):
+    """ The main company page.
     """
     grok.require('waeup.Public')
     grok.name('index')
-    grok.context(IInstitution)
+    grok.context(ICompany)
     pnav = 0
     label = ''
@@ -434,5 +434,5 @@
     """
     grok.name('administration')
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.require('waeup.managePortal')
     label = _(u'Administration')
@@ -443,7 +443,7 @@
     """
     grok.name('feed.rss')
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.require('waeup.Public')
-    grok.template('institutionrss20feed')
+    grok.template('companyrss20feed')
 
     name = 'General news feed'
@@ -457,5 +457,5 @@
     @property
     def title(self):
-        return getattr(grok.getSite(), 'name', u'Sample Institution')
+        return getattr(grok.getSite(), 'name', u'Sample Company')
 
     @property
@@ -1568,5 +1568,5 @@
     """Captcha'd page for all kind of users to request a password change.
     """
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.name('changepw')
     grok.require('waeup.Anonymous')
@@ -405,13 +405,13 @@
 
 #
-# Institution related pages...
+# Company related pages...
 #
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_permissions.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_permissions.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_permissions.py	(revision 11954)
@@ -31,5 +31,5 @@
 from zope.security.interfaces import Unauthorized
 from zope.testbrowser.testing import Browser
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.testing import (
     FunctionalLayer, FunctionalTestCase, get_all_loggers, remove_new_loggers,
@@ -58,6 +58,6 @@
     def setUp(self):
         super(PermissionTest, self).setUp()
-        # Set up a complete institution to have every page available...
-        app = Institution()
+        # Set up a complete company to have every page available...
+        app = Company()
         self.getRootFolder()['app'] = app
         setSite(self.getRootFolder()['app'])
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/interfaces.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/interfaces.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/interfaces.py	(revision 11954)
@@ -253,5 +253,5 @@
     EXAM_SUBJECTS_DICT = Attribute("Dict of examination subjects")
     EXAM_GRADES = Attribute("Dict of examination grades")
-    INST_TYPES_DICT = Attribute("Dict if institution types")
+    INST_TYPES_DICT = Attribute("Dict if company types")
     STUDY_MODES_DICT = Attribute("Dict of study modes")
     APP_CATS_DICT = Attribute("Dict of application categories")
@@ -288,6 +288,6 @@
     """
 
-class IInstitution(IIkobaObject):
-    """Representation of an institution.
+class ICompany(IIkobaObject):
+    """Representation of an company.
     """
 
@@ -593,11 +593,11 @@
 
     name = schema.TextLine(
-        title = _(u'Name of Institution'),
-        default = _(u'Sample Institution'),
+        title = _(u'Name of Company'),
+        default = _(u'Sample Company'),
         required = True,
         )
 
     acronym = schema.TextLine(
-        title = _(u'Abbreviated Title of Institution'),
+        title = _(u'Abbreviated Title of Company'),
         default = u'WAeUP.Ikoba',
         required = True,
@@ -796,8 +796,8 @@
     Components implementing this interface are referred to as
     'plugins'. They are normally called when a new
-    :class:`waeup.ikoba.app.Institution` instance is created.
+    :class:`waeup.ikoba.app.Company` instance is created.
 
     Plugins can setup and update parts of the central site without the
-    site object (normally a :class:`waeup.ikoba.app.Institution` object)
+    site object (normally a :class:`waeup.ikoba.app.Company` object)
     needing to know about that parts. The site simply collects all
     available plugins, calls them and the plugins care for their
@@ -852,5 +852,5 @@
     Utilities providing this interface are looked up when a Pluggable
     Authentication Utility (PAU) for any
-    :class:`waeup.ikoba.app.Institution` instance is created and put
+    :class:`waeup.ikoba.app.Company` instance is created and put
     into ZODB.
 